#
# File:    ./tests/unit/__init__.py
# Author:  Jiří Kučera <sanczes AT gmail.com>
# Date:    2022-06-24 14:03:43 +0200
# Project: vutils-python: Python language tools
#
# SPDX-License-Identifier: MIT
#
"""Unit tests for :mod:`vutils.python`."""
